Documentation
¶
Overview ¶
Package setlogsinks set organization log sinks to pubsub
Instances ¶
Multiple.
At least one to export gsuite admin logs, related to groups members and groups settings, from GCP Cloud Audit Logs at organization level.
Output ¶
Logging sink export set up.
Notes ¶
- The sink can only export logs belonging to the parent resource.
- gSuite admin Logs belongs to the related GCP organization.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InstanceDeployment ¶
type InstanceDeployment struct {
DumpTimestamp time.Time `yaml:"dumpTimestamp"`
Artifacts struct {
SinkName string `yaml:"sinkName"`
Destination string
TopicFullName string `yaml:"topicFullName"`
}
Core *deploy.Core
Settings struct {
Service struct {
GSU gsu.Parameters
IAM iamgt.Parameters
GCB gcb.Parameters
}
Instance struct {
LSK lsk.Parameters
}
}
}
InstanceDeployment settings and artifacts structure
func NewInstanceDeployment ¶
func NewInstanceDeployment() *InstanceDeployment
NewInstanceDeployment create deployment structure with default settings set
func (*InstanceDeployment) Deploy ¶
func (instanceDeployment *InstanceDeployment) Deploy() (err error)
Deploy a service instance
func (*InstanceDeployment) ReadValidate ¶
func (instanceDeployment *InstanceDeployment) ReadValidate() (err error)
ReadValidate reads and validates service and instance settings
func (*InstanceDeployment) Situate ¶
func (instanceDeployment *InstanceDeployment) Situate() (err error)
Situate complement settings taking in account the situation for service and instance settings